@@ -99,7 +99,7 @@ class FileNameFormat:
 
 @singledispatch
 def extract_format_params(file: JubeatFile) -> FormatParameters:
-    ...
+    raise ValueError(f"Unexpected argument : {file}")
 
 
 @extract_format_params.register
