@@ -27,9 +27,9 @@ from .symbols import (
 )
 
 DIFFICULTIES = {
-    1: Difficulty.BASIC,
-    2: Difficulty.ADVANCED,
-    3: Difficulty.EXTREME,
+    1: Difficulty.BASIC.value,
+    2: Difficulty.ADVANCED.value,
+    3: Difficulty.EXTREME.value,
 }
 
 SYMBOL_TO_BEATS_TIME = {c: BeatsTime("1/4") * i for i, c in enumerate(NOTE_SYMBOLS)}
@@ -385,7 +385,7 @@ class JubeatAnalyserParser:
         elif self.circle_free and bpp == 1:
             raise ValueError("Can't set #bpp to 1 when #circlefree is on")
         else:
-            self.bytes_per_panel = int(value)
+            self.bytes_per_panel = bpp
 
     def do_holdbyarrow(self, value: str) -> None:
         self.hold_by_arrow = int(value) == 1
