@@ -8,6 +8,7 @@ from typing import Dict, Iterator, List, Union
 
 from more_itertools import collapse, intersperse, mark_ends, windowed
 
+from jubeatools.info import __repository_url__, __version__
 from jubeatools.song import (
     BeatsTime,
     Chart,
@@ -18,7 +19,6 @@ from jubeatools.song import (
     Timing,
 )
 from jubeatools.utils import lcm
-from jubeatools.version import __version__
 
 from ..dump_tools import (
     DIRECTION_TO_ARROW,
@@ -228,7 +228,7 @@ def _dump_memo1_chart(
     # Actual output to file
     file = StringIO()
     file.write(f"// Converted using jubeatools {__version__}\n")
-    file.write(f"// https://github.com/Stepland/jubeatools\n\n")
+    file.write(f"// {__repository_url__}\n\n")
     file.write(
         "\n\n".join(section.render(circle_free) for _, section in sections.items())
     )
