@@ -87,7 +87,9 @@ def load_timing_info(
 
 def load_notes(events: List[malody.Event]) -> List[Union[song.TapNote, song.LongNote]]:
     # filter out sound events
-    notes = filter(lambda e: isinstance(e, (malody.TapNote, malody.LongNote)), events)
+    notes: List[Union[malody.TapNote, malody.LongNote]] = [
+        e for e in events if isinstance(e, (malody.TapNote, malody.LongNote))
+    ]
     return [load_note(n) for n in notes]
 
 
