@@ -8,13 +8,17 @@ parse than existing "memo-like" formats (memo, youbeat, etc ...).
 https://github.com/Stepland/memon
 """
 
-from .v0 import (
+from .v0.dump import (
     dump_memon_0_1_0,
     dump_memon_0_2_0,
     dump_memon_0_3_0,
     dump_memon_legacy,
+)
+from .v0.load import (
     load_memon_0_1_0,
     load_memon_0_2_0,
     load_memon_0_3_0,
     load_memon_legacy,
 )
+from .v1.dump import dump_memon_1_0_0
+from .v1.load import load_memon_1_0_0
