@@ -1,7 +1,7 @@
 from pathlib import Path
 from typing import Any, Dict, List, Protocol
 
-from jubeatools.formats.filetypes import ChartFile
+from jubeatools.formats.filetypes import ChartFile, SongFile
 from jubeatools.song import Song
 
 
@@ -24,6 +24,14 @@ class ChartFileDumper(Protocol):
         ...
 
 
+class SongFileDumper(Protocol):
+    """Generic signature of internal dumper for formats that use a single file
+    to hold all charts of a song"""
+
+    def __call__(self, song: Song, **kwargs: Any) -> SongFile:
+        ...
+
+
 class Loader(Protocol):
     """A Loader deserializes a Path to a Song object and possibly takes in
     some options via the kwargs.
