@@ -1,6 +1,8 @@
-"""Provides the Song class, the central model for chartsets
-Every input format is converted to a Song instance
-Every output format is created from a Song instance
+"""
+Provides the :py:obj:`Song` class, the central model for chartsets
+
+- Every input format is converted to a :py:obj:`Song` instance
+- Every output format is created from a :py:obj:`Song` instance
 
 Most timing-related info is stored as beat fractions, otherwise a decimal
 number of seconds is used"""
@@ -21,7 +23,6 @@ from typing import (
     Iterable,
     Iterator,
     List,
-    Mapping,
     Optional,
     Sequence,
     Set,
@@ -31,7 +32,9 @@ from typing import (
 
 from jubeatools.utils import none_or
 
+#: A time measured in beats
 BeatsTime = Fraction
+#: A time measured in seconds
 SecondsTime = Decimal
 
 
@@ -85,15 +88,18 @@ class Position:
 
 @dataclass(frozen=True, order=True)
 class NotePosition(Position):
-    """A specific square on the controller. (0, 0) is the top-left button, x
+    """
+    A specific square on the controller. (0, 0) is the top-left button, x
     goes right, y goes down.
 
-        x →
-        0 1 2 3
-    y 0 □ □ □ □
-    ↓ 1 □ □ □ □
-      2 □ □ □ □
-      3 □ □ □ □
+    ::
+
+            x →
+            0 1 2 3
+        y 0 □ □ □ □
+        ↓ 1 □ □ □ □
+          2 □ □ □ □
+          3 □ □ □ □
 
     The main difference with Position is that x and y MUST be between 0 and 3
     """
@@ -271,15 +277,24 @@ class Difficulty(str, Enum):
     ADVANCED = "ADV"
     EXTREME = "EXT"
 
+    def __str__(self) -> str:
+        return self.value
+
 
 @dataclass
 class Song:
     """The abstract representation format for all jubeat chart sets.
     A Song is a set of charts with associated metadata"""
 
+    #: Miscellaneous information about the song
     metadata: Metadata
-    charts: Mapping[str, Chart] = field(default_factory=dict)
+    #: A regular dict that maps a difficulty name to a :py:obj:`Chart`.
+    #: The names for the usual jubeat difficulties should be ``"BSC"``, ``"ADV"``,
+    #: and ``"EXT"``
+    charts: Dict[str, Chart] = field(default_factory=dict)
+    #: The optional shared timing object that applies to all charts by default
     common_timing: Optional[Timing] = None
+    #: The optional shared set of HAKUs that apply to all charts by default
     common_hakus: Optional[Set[BeatsTime]] = None
 
     @classmethod
