@@ -24,6 +24,20 @@ def dump_and_load_then_compare(
     load_options: Optional[dict] = None,
     dump_options: Optional[dict] = None,
 ) -> None:
+    recovered_song = dump_and_load(
+        format_, song, bytes_decoder, temp_path, load_options, dump_options
+    )
+    assert recovered_song == song
+
+
+def dump_and_load(
+    format_: Format,
+    song: song.Song,
+    bytes_decoder: Callable[[bytes], str] = lambda b: b.decode("utf-8"),
+    temp_path: Callable[[], ContextManager[Path]] = open_temp_dir,
+    load_options: Optional[dict] = None,
+    dump_options: Optional[dict] = None,
+) -> song.Song:
     load_options = load_options or {}
     dump_options = dump_options or {}
     loader = LOADERS[format_]
@@ -39,4 +53,4 @@ def dump_and_load_then_compare(
         recovered_song = loader(folder_path, **load_options)
         recovered_song.minimize_timings()
         recovered_song.minimize_hakus()
-        assert recovered_song == song
+        return recovered_song
